@@ -809,6 +809,8 @@ fn prepare_command_line() -> bool {
         )
         .get_matches();
 
+    let default_addr;
+
     unsafe {
         let Config { accounts, .. } = Config::get();
 
@@ -832,18 +834,21 @@ fn prepare_command_line() -> bool {
         }
 
         // default account
-        accounts.push(MessageInfo {
-            sender: HumanAddr(format!("{}{}", DENOM, DEFAULT_SENDER_ADDR)),
-            // there is default account with balance
-            sent_funds: vec![Coin {
-                denom: DENOM.to_string(),
-                amount: Uint128::from(DEFAULT_SENDER_BALANCE),
-            }],
-        });
+        if accounts.is_empty() {
+            accounts.push(MessageInfo {
+                sender: HumanAddr::from(format!("{}{}", DENOM, DEFAULT_SENDER_ADDR)),
+                // there is default account with balance
+                sent_funds: vec![Coin {
+                    denom: DENOM.to_string(),
+                    amount: Uint128::from(DEFAULT_SENDER_BALANCE),
+                }],
+            });
+        }
 
         // Sort by sender address
-
         accounts.sort_by(|a, b| a.sender.cmp(&b.sender));
+        // set default addr
+        default_addr = accounts[0].sender.as_str();
     }
 
     if let Some(file) = matches.value_of("run") {
@@ -879,7 +884,7 @@ fn prepare_command_line() -> bool {
                         editor.add_input_history_entry(k.to_owned());
                     }
                 }
-                return start_simulate_forever(contract_addr.as_str(), DEFAULT_SENDER_ADDR);
+                return start_simulate_forever(contract_addr.as_str(), default_addr);
             }
             Err(e) => {
                 println!("watch error: {}", e.to_string().red());
